#ifndef _LINUX_HDREG_H
#define _LINUX_HDREG_H

/* Register definitions for IBM PS/2 MFM controller */

#define ATTN_REG	0x324		/* Attention register */
#define DATA_REG	0x320		/* Data Register */
#define CTRL_REG	0x322		/* Adapter control register */
#define STAT_REG	0x322		/* Adapter status register */
#define INTS_REG	0x324		/* Interrupt status register */

/* Status register bits */
#define SR_DRQ		0x10		/* Data request */
#define SR_BSY		0x04		/* Busy */
#define SR_TE		0x01		/* Transfer Enable */

/* Interrupt status register bits */
#define ISR_ERR		0x80		/* Termination Error */
#define ISR_INVCMD	0x40		/* Invalid Command */
#define ISR_CMDRCT	0x20		/* Command Reject */
#define ISR_DS		0x04		/* Drive Selected */
#define ISR_ERPI	0x02		/* Error Recovery Invoked */
#define ISR_EQPCHK	0x01		/* Equipment Check */

/* Attention register bits */
#define AR_SSSB		0x20		/* Send sense summary block */
#define AR_SCCB		0x80		/* Send command control block */
#define AR_SCSB		0x40		/* Send command specify block */
#define	AR_DRQ		0x10		/* Data request */

/* Values for hard disk commands */
#define WIN_READDATA	0x10		/* Read Data */
#define WIN_READCHECK	0x20		/* Read Check */
#define WIN_READTRANS	0x30		/* Read Transparent */
#define WIN_READID	0x50		/* Read ID */
#define WIN_RECAL	0x80		/* Recalibrate */
#define WIN_WRITEDATA	0x90		/* Write Data */
#define WIN_WRITEVFY	0xA0		/* Write Verify */
#define WIN_WRITETRANS	0xB0		/* Write Transparent */
#define WIN_FORMAT	0xD0		/* Format Disk */
#define WIN_SEEK	0xE0		/* Seek */
#define WIN_FORMATCYL	0xF0		/* Format Cylinder */
#define WIN_SPECIFY	4711		/* Pseudo command, not supported
					   by the controller ! */

/* Values for the command specify block */
#define CSB0		0x8F    	/* Error correction, 16 retrys */
#define CSB1    	0x83    	/* ST506 with 5 Mbps */
#define CSB2    	0x0B    	/* Gap 1 length */
#define CSB3    	0x04    	/* Gap 2 length */
#define CSB4    	0x1B    	/* Gap 3 length */
#define CSB5    	0x0D    	/* Sync length */
#define CSB6    	0x00    	/* Step rate 25 usec */
#define CSB7    	0x00    	/* N/A */

    /* Well, I can't believe it, too. But the Tech. Reference
       says, Byte 8 & 9 have to be 0x00 */

#define CSB8    	0x00    	/* Write Precomp */
#define CSB9   	 	0x00    	/* Write Precomp */
 

/* Values for the command control block */
#define CCB_BASE	0x05		/* Transmit Data to adapter,
					   Auto Seek,
					   Not skip controlled sectors
					   ECC operation */
#define SL_128		0x00		/* Sector Length = 128 */
#define SL_256		0x01		/* Sector Length = 256 */
#define SL_512		0x02		/* Sector Length = 512 */
#define SL_1024		0x03		/* Sector Length = 1024 */	

/* Value for the adapter control register */
#define ACR_BASE	0x40		/* Base definitions for ACR */
#define ACR_16BIT	0x24		/* Enable 16 Bit transfers */
#define ACR_GATEINT	0x02		/* Gate Int. Request to IRQ14 */
#define ACR_DMA		0x01		/* Enable DMA transfers */

/* HD_GETGEO is the preferred choice - HDIO_REQ will be removed at some
   later time */
#define HDIO_REQ	0x301
#define HDIO_GETGEO	0x301
struct hd_geometry {
	unsigned char heads;
	unsigned char sectors;
	unsigned short cylinders;
	unsigned long start;
};
#endif
